.. toctree::
    :maxdepth: 2
    :caption: API Documentation

    api/paulicirc
    api/paulicirc.builders
    api/paulicirc.circuits
    api/paulicirc.gadgets
    api/paulicirc.layers
    api/paulicirc.utils
    api/paulicirc.utils.numpy
    api/paulicirc.utils.options
